// Ansteuerung eines Lautsprechers an Pin 1.2
// 2010-12-17: von jl erstellt

#include "speaker.h"
#include "io430.h"
#include "intrinsics.h"

static void (*wdtCallback)(void);

#pragma vector = WDT_VECTOR
__interrupt void WDT_ISR(void)
{
  wdtCallback();
}

void initialize(void (*callback)(void))
{
  wdtCallback = callback;
  
  WDTCTL = WDTPW | WDTTMSEL;
  
  BCSCTL1 = CALBC1_1MHZ;
  DCOCTL = CALDCO_1MHZ;
  
  P1DIR &= ~BIT2; // Sound erst aus!
  P1SEL |= BIT2;
  
  TACCR0 = 1000000/440/2;
  
  TACCTL1 = OUTMOD_4;
  TACTL = MC_1 | TASSEL_2 | TACLR;
  
  IE1 |= WDTIE;
  __enable_interrupt();
}

void setPeriodInMicroSeconds(unsigned int period)
{
  TACCR0 = period/2;
  TACTL |= TACLR;
}

static unsigned const int periods[] = {7645, 7215, 6810, 6428, 6067, 5727, 5405, 5102, 4816, 4545, 4290, 4050};

void setPitch(Pitch note)
{
  setPeriodInMicroSeconds(periods[note]);
}

void outputSound(bool soundOn)
{
  if(soundOn)
  {
    P1DIR |= BIT2;
  }
  else
  {
    P1DIR &= ~BIT2;
  }
}